function lambda = maxEigenvalue(M, tol, maxIters)

if ~exist('tol','var')
  tol = 1e-6;
end
if ~exist('maxIters','var')
  maxIters = 1000;
end

v = rand(size(M,2));
v = v / norm(v);
lambda = 1;
delta = 2*tol;

ii = 0;
while (delta > tol) & (ii < maxIters)
  ii = ii + 1;
  lambdaOld = lambda;
  v(:) = M*v;
  lambda = norm(v);
  v(:) = v / lambda;
  delta = abs(lambda - lambdaOld);
end

if (ii == maxIters)
  errors('maxEigenvalue did not converge');
end

return

%% Test

N = 14;
M = rand(N,N);
v = eig(M);
max(real(v))
lambda = maxEigenvalue(M)

%%

N = 14;
tmp = rand(N,N);
M = tmp' * tmp;
v = eig(M);
max(real(v))
lambda = maxEigenvalue(M)

%%

N = 14;
tmp = rand(N,N);
W = tmp' * tmp;
y = rand(N,1);
v = eig(M*diag(y));
max(real(v))
lambda = maxEigenvalue(M*diag(y))

