function W = combineNormalizationWeights(Wtheta, Wxi, combinationType)
%
% Wtheta: weights over orientation preference
% Wxi: weights over space (RF center locations)
% combinationType: 'separable' or 'inseparable' (default)
%
% W is a great big matrix of normalization weights over both orientation
% and position.
%
% DJH, 9/2019
% Copyright (c) 2019, David J. Heeger, New York University

if ~exist('combinationType','var')
  % combinationType = 'separable';
  combinationType = 'inseparable';
end

% Number of neurons
Ntheta = size(Wtheta,1);
Nxi = size(Wxi,1);
N = Nxi * Ntheta;

W = zeros(N,N);
kk = 1;
Wtmp = zeros(Nxi,Ntheta);
for jj = 1:Ntheta
  for ii = 1:Nxi
    Wtmp(:) = 0;
    if strcmp(combinationType,'separable')
      Wtmp(:,:) =  Wxi(ii,:)' * Wtheta(jj,:);
    elseif strcmp(combinationType,'inseparable')
      Wxi(ii,ii) = 0;
      Wtmp(:,jj) = Wxi(ii,:)';
      Wtmp(ii,:) = Wtheta(jj,:);
    end
    W(kk,:) = Wtmp(:);
    kk = kk + 1;
  end
end

% Scale the normalization weights so that the summed responses (across
% orientation preferencs) = 1 for a full contrast and full field grating.
ztmp = zeros(Nxi,Ntheta);
ztmp(:,1) = 1;
Wscale = max(W * ztmp(:))
if strcmp(combinationType,'separable')
  Wscale = Wscale / 1;
elseif strcmp(combinationType,'inseparable')
  Wscale = Wscale / 2.5;
end
W = W / Wscale;

return
