

%% Run it and save responses

% *** Set recomputeIt = 1 to re-run the simulations ***
% recomputeIt = 1;
recomputeIt = 0;

% For debugging
% stimulusSizes = [0.5 2 8];
% stimulusContrasts = [sqrt(2)/2 1.0];

if recomputeIt
  parameters;
  figurePath = 'Figures/Fig 6/';
  stimulusPattern = 'grating';
  stimulusSizes = [0.25 0.5 1 2 4 8];
  stimulusContrasts = [0.0625 0.125 0.25 0.5 sqrt(2)/2 1.0];
  % stimulusSizes = [0.5 2 8]; % for debugging
  % stimulusContrasts = [sqrt(2)/2 1.0]; % for debugging
  computeFig7;
  
  parameters;
  figurePath = 'Figures/Fig 6/';
  stimulusPattern = 'plaid';
  stimulusSizes = [0.25 0.5 1 2 4 8];
  % stimulusSizes = [0.5 2 8]; % for debugging
  stimulusContrasts = [1.0];
  computeFig7;
end

%% Re-load responses

clear all;
load('Figures/Fig 6/gratingResponses.mat');
yGratings = yAll;
gratingContrasts = stimulusContrasts;
nGratingContrasts = length(gratingContrasts);
nSizes = length(stimulusSizes);

load('Figures/Fig 6/plaidResponses.mat');
yPlaids = yAll;
plaidContrasts = stimulusContrasts;
nPlaidContrasts = length(plaidContrasts);

figurePath = 'Figures/Fig 6/';

%% Analysis

% Mean response from center RF, averaged over preferred orientations and
% phases. Pick either firing rates or rectified membrane potentials.
%    size(yAll) is [T, Nxi, Ntheta, nPhases, nSizes, nContrasts]
xiID = find(abs(xiPreferred-sCenter) == min(abs(xiPreferred-sCenter)));
% ycGratings = squeeze(yGratings(:,xiID,:,:,:,:));
% gratingResponses = squeeze(sum(sum(ycGratings,3),2));
ycGratings = squeeze(yGratings(:,xiID,7,:,:,:));
gratingResponses = squeeze(sum(ycGratings,2));
% ycPlaids = squeeze(yPlaids(:,xiID,:,:,:,:));
% plaidResponses = squeeze(sum(sum(ycPlaids,3),2));
ycPlaids = squeeze(yPlaids(:,xiID,7,:,:,:));
plaidResponses = squeeze(sum(ycPlaids,2));

% Crop initial transient 
cropID = (t >= cropDuration);
tCrop = t(cropID);
rCropGratings = gratingResponses(cropID,:,:);
rCropPlaids = plaidResponses(cropID,:,:);

% Frequencies
F = length(tCrop);
Fs = 1/(deltaT/1000);
f = Fs/2 * linspace(0,1,F/2+1)';

% Fourier amp of responses: gratings
rAmpGratings = abs(fft(rCropGratings))/F;
rAmpGratings = rAmpGratings([1:length(f)],:,:);
rAmpGratings(1,:,:) = 0;
for ff = 1:10
  fID = (f == ff*1000*stimulusTF);
  rAmpGratings(fID,:,:) = 0;
end

% Fourier amp of responses: plaids
rAmpPlaids = abs(fft(rCropPlaids))/F;
rAmpPlaids = rAmpPlaids([1:length(f)],:,:);
rAmpPlaids(1,:,:) = 0;
% for ff = 1:10
%   fID = (f == ff*1000*stimulusTF);
%   rAmpPlaids(fID,:,:) = 0;
% end

% Crop frequencies below 30 Hz and above 200 Hz
fRange = [30 200];
fID = (f < fRange(1)) | (f > fRange(2));
rAmpGratings(fID,:,:) = 0;
rAmpPlaids(fID,:,:) = 0;

% Compute mean response amplitudes, oscilation amplitudes, and oscillation
% frequencies: gratings
meanResponseGratings = zeros([nSizes nGratingContrasts]);
oscFreqGratings = NaN*ones([nSizes nGratingContrasts]);
oscAmpGratings = zeros([nSizes nGratingContrasts]);
for cc = 1:nGratingContrasts
  for ss = 1:nSizes
    meanResponseGratings(ss,cc) = mean(rCropGratings(:,ss,cc));
    maxID = min(find(max(rAmpGratings(:,ss,cc)) == rAmpGratings(:,ss,cc)));
    % oscAmp(ss,cc) = std(rCrop(:,ss,cc));
    oscAmpGratings(ss,cc) = sqrt(sum(rAmpGratings(:,ss,cc).^2));
    if (oscAmpGratings(ss,cc) > 0.01)
      oscFreqGratings(ss,cc) = f(maxID);
    end
  end
end

% Compute mean response amplitudes, oscilation amplitudes, and oscillation
% frequencies: plaids
meanResponsePlaids = zeros([nSizes nPlaidContrasts]);
oscFreqPlaids = NaN*ones([nSizes nPlaidContrasts]);
oscAmpPlaids = zeros([nSizes nPlaidContrasts]);
for cc = 1:nPlaidContrasts
  for ss = 1:nSizes
    meanResponsePlaids(ss,cc) = mean(rCropPlaids(:,ss,cc));
    maxID = min(find(max(rAmpPlaids(:,ss,cc)) == rAmpPlaids(:,ss,cc)));
    % oscAmp(ss,cc) = std(rCrop(:,ss,cc));
    oscAmpPlaids(ss,cc) = sqrt(sum(rAmpPlaids(:,ss,cc).^2));
    if (oscAmpPlaids(ss,cc) > 0.01)
      oscFreqPlaids(ss,cc) = f(maxID);
    end
  end
end

%% Plot response amplitudes, oscillation amplitudes, oscillation frequencies

% Change color map
cmapVals = [nGratingContrasts-1:-1:0]' / nGratingContrasts;
cmap = repmat(cmapVals,1,3);
set(groot,'defaultAxesColorOrder',cmap);

% Plot mean response amplitudes
figure(1); clf;
subplot(3,1,1);
semilogx(stimulusSizes, meanResponseGratings, 'o-', 'MarkerFaceColor', 'auto');
hold on
semilogx(stimulusSizes, meanResponsePlaids, 'ko--', 'color', [0 0.4470 0.7410], 'MarkerFaceColor', 'auto');
hold off
xlim([min(stimulusSizes) max(stimulusSizes)]);
set(gca,'xtick',stimulusSizes);
ylim([0 0.5]);
set(gca,'ytick',[0:0.25:0.5]);
set(gca,'Clipping','off');
xlabel('Stimulus size (deg)');
title('Response amplitude');
drawPublishAxis

% Plot oscilation amplitudes
subplot(3,1,2);
semilogx(stimulusSizes, oscAmpGratings, 'o-', 'MarkerFaceColor', 'auto');
hold on
semilogx(stimulusSizes, oscAmpPlaids, 'ko--', 'color', [0 0.4470 0.7410], 'MarkerFaceColor', 'auto');
hold off
xlim([min(stimulusSizes) max(stimulusSizes)]);
set(gca,'xtick',stimulusSizes);
ylim([0 0.2]);
set(gca,'ytick',[0:0.1:0.2]);
xlabel('Stimulus size (deg)');
title('Oscillation amplitude');
drawPublishAxis

% Plot oscillation frequencies
subplot(3,1,3);
semilogx(stimulusSizes, oscFreqGratings, 'o-', 'MarkerFaceColor', 'auto');
hold on
semilogx(stimulusSizes, oscFreqPlaids, 'ko--', 'color', [0 0.4470 0.7410], 'MarkerFaceColor', 'auto');
hold off
xlim([min(stimulusSizes) max(stimulusSizes)]);
set(gca,'xtick',stimulusSizes);
ylim([35 50]);
set(gca,'ytick',[35:5:50]);
xlabel('Stimulus size (deg)');
title('Oscillation frequency');
drawPublishAxis

print([figurePath,'/responsesOscillations.eps'],'-depsc','-painters');

% Restore color map
set(groot,'defaultAxesColorOrder',defaultColors);

%% Plot time series and Fourier amplitudes

% Subsample time for plotting
tSkip = floor(deltaTPlot / deltaT);

% Plot response time series
figure(2); clf;
yScale = 1;
for cc = 1:nGratingContrasts
  for ss = 1:nSizes
    contrast = gratingContrasts(cc);
    stimulusSize = stimulusSizes(ss);
    subplot(nSizes, nGratingContrasts, nGratingContrasts*(ss-1)+cc);
    plot(t(1:tSkip:end),gratingResponses(1:tSkip:end,ss,cc));
    xlim([0 stimulusDuration]);
    set(gca,'xtick',[0:cropDuration:stimulusDuration]);
    ylim([0 yScale]);
    xlabel('Time (msec)');
    title(['contrast=',num2str(contrast),' size=',num2str(stimulusSize)]);
    drawPublishAxis
  end
end
print([figurePath,'/responses.eps'],'-depsc','-painters');

% Plot Fourier amplitude of responses
figure(3); clf;
fScale = 0.2;
fPlotRange = [0 100];
plotID = (f >= min(fPlotRange)) & (f <= max(fPlotRange));
for cc = 1:nGratingContrasts
  for ss = 1:nSizes
    contrast = gratingContrasts(cc);
    stimulusSize = stimulusSizes(ss);
    subplot(nSizes, nGratingContrasts, nGratingContrasts*(ss-1)+cc);
    plot(f(plotID), rAmpGratings(plotID,ss,cc));
    xlim(fPlotRange);
    set(gca,'xtick',[0:20:100]);
    ylim([0 fScale]);
    xlabel('Frequency (Hz)');
    title(['contrast=',num2str(contrast),' size=',num2str(stimulusSize)]);
    drawPublishAxis
  end
end
print([figurePath,'/amplitudeSpectra.eps'],'-depsc','-painters');
