parameters;
figurePath = 'Figures/Fig S1/';

%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot receptive fields and suppressive fields %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Run it
[theta, deltaTheta, thetaPreferred, thetaRFs, ...
  xi, deltaXi, xiPreferred, xiRFs, ...
  Wyy, Wtheta, Wxi] = ...
  makeRFs(Ntheta, overlapTheta, overlapXi, FOV);
Ntheta = length(thetaPreferred);
Nxi = length(xiPreferred);

% Rescale spatial RFs for plotting
sumXiRFs = sqrt(max(sum(xiRFs.^2)));
xiRFsScaled = xiRFs / sumXiRFs;

% Compute RF sizes (ignoring the RFs on the ends for which the difference
% in RF centers is not a proper estimate of RF size)
%diff1 = abs(abs(xiPreferred) - abs(circshift(xiPreferred,[0,overlapXi])));
%diff2 = abs(abs(xiPreferred) - abs(circshift(xiPreferred,[0,-overlapXi])));
diff1 = abs(xiPreferred - circshift(xiPreferred,[0,overlapXi]));
diff2 = abs(xiPreferred - circshift(xiPreferred,[0,-overlapXi]));
RFsizes = diff1+diff2;
RFsizes(1:overlapXi) = NaN; RFsizes(end-overlapXi+1:end) = NaN;

% Compute suppressive fields
suppressiveFields = Wxi*(xiRFs.^2);

% Create color map for RF center
skip = 3;
nCurves = Nxi/3;
cmapHot = colormap(hot);
cmapHot = cmapHot(1:42,:);
cmapHotFlip = cmapHot(end:-1:1,:);
cmapTmp = [cmapHotFlip; [0,0,0]; cmapHot];
nColors = size(cmapTmp,1);
cmap = ones(nCurves,3);
for ii = 1:3
  cmap(:,ii) = interp1(linspace(-1,1,nColors)', cmapTmp(:,ii), linspace(-1,1,nCurves)');
end

figure(1); clf;
subplot(6,1,1)
thetaRFsScaled = thetaRFs / deltaTheta;
plot(theta*180/pi, thetaRFs');
hold on
plot(theta*180/pi, sum(thetaRFs.^2), 'k');
hold off
xlim([-90 90]);
set(gca,'xtick',[-90:45:90]);
ylim([0 1]);
set(gca,'ytick',[0:0.5:1]);
xlabel('Orientation');
title('Tuning curves');
drawPublishAxis

subplot(6,1,2)
cID = floor(Ntheta/2)+1;
plot(theta*180/pi, thetaRFs(cID,:));
xlim([-90 90]);
set(gca,'xtick',[-90:45:90]);
xlabel('Orientation');
title('Tuning curve');
drawPublishAxis

subplot(6,1,3)
set(groot,'defaultAxesColorOrder',cmap);
plot(xi*180/pi, xiRFsScaled([1:skip:end],:)');
hold on
plot(xi*180/pi, sum(xiRFsScaled.^2)', 'k');
hold off
xlim(1.1*FOV);
set(gca,'xtick',[FOV(1):30:FOV(2)]);
ylim([0 1]);
set(gca,'ytick',[0:0.5:1]);
xlabel('Spatial position (deg visual angle)');
title('Spatial RFs')
drawPublishAxis
set(groot,'defaultAxesColorOrder',defaultColors);

subplot(6,1,4)
cID = floor(Nxi/2)+1;
plot(xi*180/pi, xiRFsScaled(cID,:));
xlim([-4 4]);
set(gca,'xtick',[-4:1:4]);
ylim([0 1]);
set(gca,'ytick',[0:0.5:1]);
xlabel('Spatial position (deg visual angle)');
drawPublishAxis

subplot(6,1,5)
sc = max(suppressiveFields(:));
suppressiveFieldsScaled = suppressiveFields/sc;
set(groot,'defaultAxesColorOrder',cmap);
plot(xi*180/pi, suppressiveFieldsScaled(1:skip:end,:)');
xlim(1.1*FOV);
set(gca,'xtick',[-FOV(1):30:FOV(2)]);
ylim([0 1]);
set(gca,'ytick',[0:0.5:1]);
xlabel('RF center (deg visual angle');
title('Supressive fields')
drawPublishAxis
set(groot,'defaultAxesColorOrder',defaultColors);

subplot(6,1,6)
cID = floor(Nxi/2)+1;
plot(xi*180/pi, suppressiveFieldsScaled(cID,:));
xlim([-4 4]);
set(gca,'xtick',[-4:1:4]);
ylim([0 1]);
set(gca,'ytick',[0:0.5:1]);
xlabel('RF center (deg visual angle');
title('Supressive fields')
drawPublishAxis

print([figurePath,'/RFs.eps'],'-depsc','-painters');

figure(2); clf;

subplot(2,1,1)
plot(180/pi*xiPreferred, 180/pi*RFsizes ,'.k')
xlim(FOV);
set(gca,'xtick',[FOV(1):30:FOV(2)]);
ylim([0 10]);
set(gca,'ytick',[0:5:10]);
xlabel('RF center (deg visual angle)');
title('RF size (diameter at half height')
drawPublishAxis

print([figurePath,'/RF size.eps'],'-depsc','-painters');

figure(3); clf;

subplot(2,1,1)
imshow(Wyy,[],'InitialMagnification','fit');
title('Recurrent weights (Wyy)');

subplot(2,1,2)
cID = floor(Nxi/2)+1;
plot(xiPreferred*180/pi, Wyy([cID-6:cID],:)');
hold on
plot(xiPreferred*180/pi, Wyy([cID+6:-1:cID],:)');
hold off
xlim([-2 2]);
set(gca,'xtick',[-2:1:2]);
xlabel('RF center (deg visual angle)');
drawPublishAxis

%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot temporal impulse response %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Sampling
preDuration = 100;
duration = 1000;
plotDuration = 300;
t = [-preDuration:deltaT:duration-deltaT]';
[xIm,tIm,yIm] = meshgrid([1:3],t,[1:3]);

% Input: impulse
impulse = (tIm == 0) / deltaT;
yMaxImpulse = lambdaX/tauX;
stimulus = impulse; yMax = yMaxImpulse;

% Filtered output
y = recurrentQuadratureFilter(stimulus,lambdaX,omega,tauX,nFiltX,RIC,deltaT);
yCrop = squeeze(y(:,2,2,:));
yAmp = abs(yCrop);
yIntegral = sum(yCrop) * deltaT
yAmpIntegral = 0.5 * sum(yAmp) * deltaT

%%

% Plot it
figure(4); clf;

subplot(nFiltX+1,1,1);
plot(t,squeeze(stimulus(:,2,2)));
xlim([-preDuration plotDuration])
%ylim([0 1/deltaT]);
drawPublishAxis;

for nn = 1:nFiltX
  subplot(nFiltX+1,1,nn+1);
  if isreal(yCrop(:,nn))
    plot(t,yCrop(:,nn));
  else
    plot(t,[real(yCrop(:,nn)) imag(yCrop(:,nn))]);
    hold on
    plot(t, yAmp(:,nn), 'k');
    hold off
  end
  xlim([0 plotDuration])
  set(gca,'xtick',[0:100:plotDuration]);
  yMax = max(yAmp(:,nn));
  yMax = ceil(100*yMax)/100;
  ylim([-yMax yMax]);
  set(gca,'ytick',[-yMax:yMax:yMax]);
  title(['n = ',num2str(nn)]);
  drawPublishAxis;
end
print([figurePath,'tfilt1.eps'],'-depsc','-painters');

% Frequency response (this only makes sense for impulse stimulus)
yCrop2 = yCrop(t>=0,:);
F = size(yCrop2,1);
Fs = 1/(deltaT/1000);
frequencies = Fs/2 * linspace(0,1,F/2+1);
yFourierAmp = abs(fft(yCrop2))/F;
yFourierAmp = yFourierAmp(1:F/2+1,:);

% Plot it
figure(5); clf;

prefFreqs = zeros(1,nFiltX);
for nn = 1:nFiltX
  subplot(nFiltX,1,nn);
  yFourierAmpSc = yFourierAmp(:,nn) / max(yFourierAmp(:,nn));
  prefFreqs(nn) = frequencies(find(yFourierAmpSc == 1));
  loglog(frequencies(2:101), yFourierAmpSc(2:101));
  xlim([1,100])
  set(gca,'xtick',[1 2 4 10 20 40 100]);
  ylim([0.01,1]);
  %axis square;  
  title(['n = ',num2str(nn)]);
  drawPublishAxis;
end
prefFreqs

print([figurePath,'tfilt2.eps'],'-depsc','-painters');

