function [z, y, v, a, u, ge] = organicNormalization(x, variant, tauV, tauA, tauU, b0, sigma, ca, deltaT, x0, g)
%
% DJH, 9/2019
% Copyright (c) 2019, David J. Heeger, New York University

if ~exist('x0','var')
  x0 = 0;
end

if ~exist('g','var')
  g = 1;
end

T = length(x);

% Input drive
z = x;
z0 = x0;

% Run it
if (variant == 1)
  [y, v, a] = organicNormalization1(z, tauV, tauA, b0, sigma, deltaT, z0, g);
  u = zeros(size(a));
  ge = (1./a) * b0^2; 
elseif (variant == 2)
  [y, v, a, u] = organicNormalization2(z, tauV, tauA, tauU, b0, sigma, deltaT, z0, g);
  ge = (1./a).^2 * b0^2;
elseif (variant == 3)
  [y, v, a, u] = organicNormalization3(z, tauV, tauA, tauU, b0, sigma, deltaT, z0, g);
  ge = ((1+a)./a).^2 * (b0/(1+b0))^2;
elseif (variant == 4)
  [y, v, a, u] = organicNormalization4(z, tauV, tauA, tauU, b0, sigma, ca, deltaT, z0, g);
  ge = ((ca-a)./(1-a)).^2 .* ((1+a)./(ca-a)).^2 .* (b0/(1+b0))^2;
elseif (variant == 5)
  b0prime = 1/b0;
  [y, v, a, u] = organicNormalization5(z, tauV, tauA, tauU, b0prime, sigma, deltaT, z0, g);
  ge = ((1+a)./a).^2 * (1/(1+b0prime))^2;
end

return