function [y, v, a] = organicNormalization1(z, tauV, tauA, b0, sigma, deltaT, z0, g)
%
% DJH, 7/2018
% Copyright (c) 2018, David J. Heeger, New York University

if ~exist('z0','var')
  z0 = 0;
end

if ~exist('g','var')
  g = 1;
end
  
T = length(z);

% Limits
aMin = (sigma*b0)^2;

% Initialize output and temporary variables
v = zeros(size(z));
deltaV = zeros(size(z));
y = zeros(size(z));
yHat = zeros(size(z));
rootY = zeros(size(z));
a = zeros(size(z)); a(1) = aMin;
deltaA = zeros(size(z));
  
% Initial value
y0 = z0.^2 / (z0.^2 + sigma^2);
a0 = (sigma*b0)^2 / (1-y0);
v(1) = sqrt(y0);
y(1) = 0.99 * y0;
rootY(1) = sqrt(y0);
a(1) = a0;

h = waitbar(0,'Computing...');
for tt = 1:T-1
  if (round(tt/100) == tt/100)
    waitbar(tt/T,h);
  end
  
  % Compute u
  deltaA(tt) = (deltaT/tauA) * (-a(tt) + y(tt)*a(tt) + (sigma*b0)^2);
  a(tt+1) = a(tt) + deltaA(tt);
  
  % Compute yHat
  yHat(tt) = rootY(tt);
  
  % Compute v
  deltaV(tt) = (deltaT/tauV) * (-v(tt) + b0*z(tt) + g*(1-sqrt(a(tt)))*yHat(tt) );
  v(tt+1,:) = v(tt,:) + deltaV(tt,:);

  % Compute y
  y(tt+1) = max(v(tt+1),0).^2;
  rootY(tt+1) = sqrt(y(tt+1));
end
close(h);

return
