function [y, v, a, u] = organicNormalization4(z, tauV, tauA, tauU, b0, sigma, ca, deltaT, z0, g)
%
% DJH, 8/2018
% Copyright (c) 2018, David J. Heeger, New York University

if ~exist('z0','var')
  z0 = 0;
end

if ~exist('g','var')
  g = 1;
end

T = length(z);

% Limits
uMin = ((sigma*b0)/(1+b0))^2;
aMin = sqrt(uMin)/(1-sqrt(uMin));

% Initialize output and temporary variables
v = zeros(size(z));
deltaV = zeros(size(z));
y = zeros(size(z));
yHat = zeros(size(z));
rootY = zeros(size(z));
a = zeros(size(z)); a(1) = aMin;
deltaA = zeros(size(z));
u = zeros(size(z)); u(1) = uMin;
deltaU = zeros(size(z));

% Initial value
y0 = z0.^2 / (z0.^2 + sigma^2);
u0 = ((sigma*b0)/(1+b0))^2 / (1-y0);
a0 = (ca-sqrt(u0)) ./ (1+sqrt(u0));
v(1) = 0.99 * sqrt(y0);
y(1) = 0.99 * y0;
rootY(1) = 0.99 * sqrt(y0);
a(1) = 0.99 * a0;
u(1) = 0.99 * u0;

h = waitbar(0,'Computing...');
for tt = 1:T-1
  if (round(tt/100) == tt/100)
    waitbar(tt/T,h);
  end
  
  % Compute u
  deltaU(tt) = (deltaT/tauU) * (-u(tt) + y(tt)*u(tt) + uMin);
  u(tt+1) = u(tt) + deltaU(tt);
  
  % Compute a
  deltaA(tt) = (deltaT/tauA) * (-a(tt) - sqrt(u(tt)) - sqrt(u(tt))*a(tt) + ca);
  a(tt+1) = a(tt) + deltaA(tt);
  
  % Compute yHat
  yHat(tt) = rootY(tt);
  
  % Compute v
  deltaV(tt) = (deltaT/tauV) * (-v(tt) + (b0/(1+b0))*z(tt) + g*((2*a(tt))/(1+a(tt)))*yHat(tt));
  v(tt+1,:) = v(tt,:) + deltaV(tt,:);
      
  % Compute y
  y(tt+1) = max(v(tt+1),0).^2;
  rootY(tt+1) = sqrt(y(tt+1));
end
close(h);

return
