function [y, v, v1, a, u] = organicNormalizationOri(z, W, tauV, tauA, tauU, omega, b, b0, sigma, deltaT)
%
% DJH, 8/2018
% Copyright (c) 2018, David J. Heeger, New York University

% Dimensions
T = size(z,1);
N = size(z,2);

% Limits
uMin = ((sigma*b0)/(1+b0)).^2;
aMin = sqrt(uMin)./(1-sqrt(uMin));

% Initialize output and temporary variables
y = zeros(size(z));
yHat = zeros(size(z));
rootY = zeros(size(z));
y1 = zeros(size(z));
rootY1 = zeros(size(z));
v = zeros(size(z));
deltaV = zeros(size(z));
v1 = zeros(size(z));
deltaV1 = zeros(size(z));
a = zeros([T N]); a(1,:) = aMin;
deltaA = zeros([T N]);
u = zeros([T N]); u(1,:) = uMin;
deltaU = zeros([T N]);
ySum = zeros(1,N);

% Run it
h = waitbar(0,'Computing...');
for tt = 1:T-1
  if (round(tt/100) == tt/100)
    waitbar(tt/T,h);
  end
  
  % Sum across responses phases (i.e., normalized energy)
  ySum(:) = sum(y(tt,:,:),3);
  
  % Compute u
  deltaU(tt,:) = (deltaT/tauU) * (-u(tt,:) + (ySum.*u(tt,:))*W' + uMin);
  u(tt+1,:) = u(tt,:) + deltaU(tt,:);
  
  % Compute a
  deltaA(tt,:) = (deltaT/tauA) * (-a(tt,:) + sqrt(u(tt,:)) + sqrt(u(tt,:)).*a(tt,:));
  a(tt+1,:) = a(tt,:) + deltaA(tt,:);
  
  % Compute yHat
  yHat(tt,:,1) = (rootY(tt,:,1)-rootY(tt,:,2)) - 2*pi*omega*tauV*(rootY(tt,:,3)-rootY(tt,:,4));
  yHat(tt,:,2) = (rootY(tt,:,2)-rootY(tt,:,1)) - 2*pi*omega*tauV*(rootY(tt,:,4)-rootY(tt,:,3));
  yHat(tt,:,3) = 2*pi*omega*tauV*(rootY(tt,:,1)-rootY(tt,:,2)) + (rootY(tt,:,3)-rootY(tt,:,4));
  yHat(tt,:,4) = 2*pi*omega*tauV*(rootY(tt,:,2)-rootY(tt,:,1)) + (rootY(tt,:,4)-rootY(tt,:,3));
  
  % Compute v
  for pp = 1:4
    deltaV(tt,:,pp) = (deltaT/tauV) * (-v(tt,:,pp) + ...
                                       (b./(1+b)) .* z(tt,:,pp) + ...
                                       (1./(1+a(tt,:))) .* yHat(tt,:,pp) );
  end
  v(tt+1,:,:) = v(tt,:,:) + deltaV(tt,:,:);
  
  % Compute y
  y(tt+1,:,:) = max(v(tt+1,:,:),0).^2;
  rootY(tt+1,:,:) = sqrt(y(tt+1,:,:));
  
  % With feedback disabled
  for pp = 1:4
    deltaV1(tt,:,pp) = (deltaT/tauV) * (-v1(tt,:,pp) + (b./(1+b)) .* z(tt,:,pp));
  end
  v1(tt+1,:,:) = v1(tt,:,:) + deltaV1(tt,:,:);
  y1(tt+1,:,:) = max(v1(tt+1,:,:),0).^2;
  rootY1(tt+1,:,:) = sqrt(y1(tt+1,:,:));
  
end
close(h);

return
