function [y, v, v1, a, u] = organicNormalizationOriX4(z, W, Wyy, tauV, tauA, tauU, omega, b, b0, sigma, ca, deltaT)
%
% DJH, 10/2019
% Copyright (c) 2018, David J. Heeger, New York University

% Dimensions
T = size(z,1);
Nxi = size(z,2);
Ntheta = size(z,3);

% Limits
uMin = ((sigma*b0)/(1+b0)).^2;
aMin = (1-sqrt(uMin))./(1+sqrt(uMin));

% Initialize output and temporary variables
y = zeros(size(z));
yHat = zeros(size(z));
rootY = zeros(size(z));
y1 = zeros(size(z));
rootY1 = zeros(size(z));
v = zeros(size(z));
deltaV = zeros(size(z));
v1 = zeros(size(z));
deltaV1 = zeros(size(z));
a = zeros(T,Nxi,Ntheta); a(1,:,:) = aMin;
deltaA = zeros(T,Nxi,Ntheta);
u = zeros(T,Nxi,Ntheta); u(1,:,:) = uMin;
deltaU = zeros(T,Nxi,Ntheta);
ySum = zeros(1,Nxi,Ntheta);
normalizationPoolTmp = zeros(1,Nxi,Ntheta);
normalizationPool = zeros(1,Nxi,Ntheta);
uSqrt = zeros(1,Nxi,Ntheta);

% Run it
h = waitbar(0,'Computing...');
for tt = 1:T-1
  if (round(tt/100) == tt/100)
    waitbar(tt/T,h);
  end
  
  % Sum across responses phases (i.e., normalized energy)
  ySum(:) = sum(y(tt,:,:,:),4);

  % Normalization pool
  normalizationPoolTmp(:) = ySum(1,:,:).*u(tt,:,:); 
  normalizationPool(:) = W * normalizationPoolTmp(:);
  
  % Compute u
  deltaU(tt,:,:) = (deltaT/tauU) * (-u(tt,:,:) + normalizationPool + uMin);
  u(tt+1,:,:) = u(tt,:,:) + deltaU(tt,:,:);
  uSqrt(:) = sqrt((u(tt,:,:)));
  
  % Compute a
  deltaA(tt,:,:) = (deltaT/tauA) * (-a(tt,:,:) - uSqrt - uSqrt.*a(tt,:,:) + ca);
  a(tt+1,:,:) = a(tt,:,:) + deltaA(tt,:,:);  
  
  % Compute yHat
  yHat(tt,:,:,1) = (rootY(tt,:,:,1)-rootY(tt,:,:,2)) - 2*pi*omega*tauV*(rootY(tt,:,:,3)-rootY(tt,:,:,4));
  yHat(tt,:,:,2) = (rootY(tt,:,:,2)-rootY(tt,:,:,1)) - 2*pi*omega*tauV*(rootY(tt,:,:,4)-rootY(tt,:,:,3));
  yHat(tt,:,:,3) = 2*pi*omega*tauV*(rootY(tt,:,:,1)-rootY(tt,:,:,2)) + (rootY(tt,:,:,3)-rootY(tt,:,:,4));
  yHat(tt,:,:,4) = 2*pi*omega*tauV*(rootY(tt,:,:,2)-rootY(tt,:,:,1)) + (rootY(tt,:,:,4)-rootY(tt,:,:,3));
  
  for pp = 1:4
    for jj = 1:Ntheta
      yHat(tt,:,jj,pp) = Wyy * yHat(tt,:,jj,pp)';
    end
  end
  
  % Compute v
  for pp = 1:4
    deltaV(tt,:,:,pp) = (deltaT/tauV) * (-v(tt,:,:,pp) + ...
                                         (b./(1+b)) .* z(tt,:,:,pp) + ...
                                         (2*a(tt,:,:)./(1+a(tt,:,:))) .* yHat(tt,:,:,pp) );
  end
  v(tt+1,:,:,:) = v(tt,:,:,:) + deltaV(tt,:,:,:);
  
  % Compute y
  y(tt+1,:,:,:) = max(v(tt+1,:,:,:),0).^2;
  rootY(tt+1,:,:,:) = sqrt(y(tt+1,:,:,:));
  
  % With feedback disabled
  for pp = 1:4
    deltaV1(tt,:,:,pp) = (deltaT/tauV) * (-v1(tt,:,:,pp) + (b./(1+b)) .* z(tt,:,:,pp));
  end
  v1(tt+1,:,:,:) = v1(tt,:,:,:) + deltaV1(tt,:,:,:);
  y1(tt+1,:,:,:) = max(v1(tt+1,:,:,:),0).^2;
  rootY1(tt+1,:,:,:) = sqrt(y1(tt+1,:,:,:));
  
end
close(h);

return
