function [z, y, a, u] = organicNormalizationOriXsteadyState3(z1, c, W, b0, sigma)
%
% z1: input drive at full contrast (T,Nxi,Ntheta)
% c: vector of stimulus contrasts
% W: normalization weights
% b0: input gain
% sigma: semi-saturation contrast

% DJH, 9/2019
% Copyright (c) 2019, David J. Heeger, New York University

% Dimensions
Nxi = size(z1,2);
Ntheta = size(z1,1);
N = Nxi * Ntheta;

z = zeros(length(c),Nxi,Ntheta);
y = zeros(size(z));
normPool = zeros(Nxi,Ntheta);
for cc = 1:length(c)
  z(cc,:,:) = c(cc) * z1';
  zSqr = squeeze(z(cc,:,:).^2);
  normPool(:) = W * zSqr(:);
  y(cc,:,:) = zSqr ./ (normPool + sigma^2);
end

% Modulators
a = zeros(size(z));
u = zeros(size(z));
I = eye(N);
for cc = 1:length(c)
  yTmp = y(cc,:,:);
  u(cc,:) = ((sigma * b0)/(1+b0))^2 * inv(I-W*diag(yTmp(:)))*ones(N,1);
end
a(:,:,:) = sqrt(u) ./ (1-sqrt(u));

return
