%% Steady state

% Input drive
zSS = 10.^[-2:0.1:0];

% Feedforward responses
yFeedforward = zSS.^2 ./ (zSS.^2 + sigma^2);

% Limits
uMin = ((sigma*b0)/(1+b0))^2;
aMin = sqrt(uMin)/(1-sqrt(uMin));

if (variant == 1)
  aSS = (sigma * b0)^2 ./ (1-yFeedforward);
  uSS = zeros(size(aSS));
  geSS = (1./aSS) * b0^2;
  
elseif (variant == 2)
  aSS = (sigma * b0) ./ sqrt(1-yFeedforward);
  uSS = aSS.^2;
  geSS = (1./aSS).^2 * b0^2;

elseif (variant == 3)
  uSS = ((sigma * b0)/(1+b0))^2 ./ (1-yFeedforward);
  aSS = sqrt(uSS) ./ (1-sqrt(uSS));
  geSS = ((1+aSS)./aSS).^2 * (b0/(1+b0))^2;

elseif (variant == 4)
  lambda = 0.99;
  yTmp = yFeedforward;
  for cc = 1:1000
    uSS = ((sigma * b0)/(1+b0))^2 ./ (1-yTmp);
    uSS = max(uSS,uMin);
    aSS = (ca-sqrt(uSS)) ./ (1+sqrt(uSS));
    aSS = max(aSS,aMin);
    yTmp = lambda * yTmp + (1-lambda) * ((b0/(1+b0))^2 * ((1+aSS)./(1-aSS)).^2 .* zSS.^2);
  end
  geSS = ((ca-aSS)./(1-aSS)).^2 .* ((1+aSS)./(ca-aSS)).^2 .* (b0/(1+b0))^2;

elseif (variant == 5)
  b0prime = 1/b0;
  uSS = (sigma/(1+b0prime))^2 ./ (1-yFeedforward);
  aSS = sqrt(uSS) ./ (1-sqrt(uSS));
  geSS = ((1+aSS)./aSS).^2 * (1/(1+b0prime))^2;
end

% Steady state responses
ySS = geSS .* zSS.^2;
shouldBeZero = max(max(ySS-yFeedforward))
R50 = ySS(floor(length(zSS)/2)+1)

figure(1); clf;
subplot(6,1,1)
semilogx(zSS,zSS)
title('Feedforward drive: z')
drawPublishAxis

subplot(6,1,2)
semilogx(zSS,[yFeedforward' ySS'])
title('Steady state response: y')
drawPublishAxis

subplot(6,1,3)
semilogx(zSS,aSS)
title('Modulator: a')
drawPublishAxis

subplot(6,1,4)
semilogx(zSS,sqrt(uSS))
title('Modulator: u')
drawPublishAxis

subplot(6,1,5)
semilogx(zSS,geSS)
title('Effective gain: ge')
drawPublishAxis

subplot(6,1,6)
plot(yFeedforward,aSS)
title('Modulator vs response: a vs y')
drawPublishAxis

print([figurePath,'/steadyState',num2str(variant),'.eps'],'-depsc','-painters');

%% Dynamics

% Stimulus timing (msec)
totalDuration = 2 * targetDuration * length(contrasts);
t = [-preDuration:deltaT:totalDuration-deltaT]';
T = length(t);

% Input
x0 = zeros(T,1);
for cc = 1:length(contrasts)
  c = contrasts(cc);
  targetOnsetTime = 2*(cc-1) * targetDuration;
  targetOffsetTime = (2*(cc-1)+1) * targetDuration;
  id = (t>targetOnsetTime) & (t<targetOffsetTime);
  x0(id) = c;
end
x = x0;

%%%%%%%%%%
% Run it %
%%%%%%%%%%

[z, y, v, a, u, ge] = organicNormalization(x, variant, tauV, tauA, tauU, b0, sigma, ca, deltaT);

% Compute steady state responses for comparison
inputDrive = (contrasts).^2;
ySteadyState = inputDrive ./ (inputDrive + sigma^2);

%%%%%%%%%%%%%%%%%%%%
% Plot time series %
%%%%%%%%%%%%%%%%%%%%

figure(2); clf;

zScale = 1;
yScale = 2.0;
% yScale = max(y);

subplot(5,1,1);
plot(t,z);
xlim([-100,totalDuration]);
set(gca,'xtick',[0:targetDuration:totalDuration]);
ylim([-zScale zScale]);
xlabel('Time (msec)');
title('Input drive: z');
drawPublishAxis

subplot(5,1,2);
plot(t,y);
hold on
plot(t,sum(y,2),'k');
for cc = 1:length(contrasts);
  targetTime = (2*(cc-1)+1) * targetDuration;
  plot(targetTime,ySteadyState(cc),'ko');
end
plot(t,0.5*ones(size(t)),'k-.');
plot(t,ones(size(t)),'k-.');
hold off
xlim([-100,totalDuration]);
set(gca,'xtick',[0:targetDuration:totalDuration]);
ylim([0 yScale]);
xlabel('Time (msec)');
title('Responses: y');
drawPublishAxis

subplot(5,1,3);
plot(t,a);
xlim([-100,totalDuration]);
set(gca,'xtick',[0:targetDuration:totalDuration]);
xlabel('Time (msec)');
title('Modulator: a');
drawPublishAxis

subplot(5,1,4);
plot(t,sqrt(u));
xlim([-100,totalDuration]);
set(gca,'xtick',[0:targetDuration:totalDuration]);
xlabel('Time (msec)');
title('Modulator: u');
drawPublishAxis

subplot(5,1,5);
semilogy(t,ge);
xlim([-100,totalDuration]);
set(gca,'xtick',[0:targetDuration:totalDuration]);
ylim([0.01, 100]);
xlabel('Time (msec)');
title('Effective gain: ge');
drawPublishAxis

print([figurePath,'/dynamics',num2str(variant),' tauU=',num2str(tauU),'.eps'],'-depsc','-painters');
