%% Parameters

nTF = length(stimulusTFs);
nC = length(contrasts);

% Stimulus timing (msec)
targetDuration = 1250;
cropDuration = 250;

%% Run it

% Stimulus timing (msec)
t = [0:deltaT:targetDuration-deltaT]';
T = length(t);

% Initialize matrices for holding results
yAll = zeros(T,nC,nTF);
y1 = zeros(T,nC,nTF);

% make RFs
[theta, deltaTheta, thetaPreferred, thetaRFs] = makeRFs(Ntheta, overlapTheta, 1, [-1 1]);
% Number of stimulus samples
Mtheta = length(theta);
% Normalization weights
W = ones(Ntheta,Ntheta);
b = b0 * ones(1,Ntheta);

% Make full contrast stimulus
s = zeros(Mtheta,1);
s(floor(Mtheta/2)+1) = 1;
z1 = (thetaRFs * s);

for cc = 1:nC
  for ff = 1:nTF
    c = contrasts(cc);
    stimulusTF = stimulusTFs(ff);
    
    % Stimulus input
    x0 = zeros(T,1);
    id = (t<targetDuration);
    x0(id) = c;

    % x = x0 .* cos(2*pi*tf*t);
    x = x0 .* (cos(2*pi*stimulusTF*t) + i*sin(2*pi*stimulusTF*t));

    % Temporal prefilter
    xTmp = zeros(T,1,1);
    xTmp(:) = x;
    xPrefiltered = squeeze(recurrentQuadratureFilter(xTmp, lambdaX, omegaX, tauX, nFiltX, RIC, deltaT));
    xPrefiltered = xPrefiltered(:,nFiltX);
    
    % Input drive
    z = zeros(T,Ntheta,4);
    z(:,:,1) = real(xPrefiltered) * z1';
    z(:,:,2) = -real(xPrefiltered) * z1';
    z(:,:,3) = imag(xPrefiltered) * z1';
    z(:,:,4) = -imag(xPrefiltered) * z1';

    % Run it
    [y, v, v1, a, u] = organicNormalizationOri(z, W, tauV, tauA, tauU, omega, b, b0, sigma, deltaT);
    yAll(:,cc,ff) = sum(sum(y,2),3);
    y1(:,cc,ff) = sum(y(:,:,1)-y(:,:,2),2);
  end
end

%%

tID = (t >= cropDuration);
tCrop = t(tID);
yAllCrop = yAll(tID,:,:);
y1Crop = y1(tID,:,:);

% Frequencies
F = length(tCrop);
Fs = 1/(deltaT/1000);
f = Fs/2 * linspace(0,1,F/2+1)';

% Fourier amp of responses
y1DFT = fft(y1Crop);
y1Amp = abs(y1DFT)/F;
y1Amp(1,:,:) = 0;
y1Phase = atan2(imag(y1DFT), real(y1DFT));

% tfTuning is nC x nTF
tfTuning = squeeze(mean(yAllCrop));
sc = max(tfTuning');
tfTuningSc = tfTuning ./ repmat(sc',1,nTF);

% tfPhase is nC x nTF
tfPhase = zeros(nC, nTF);
for cc = 1:nC
  for ff = 1:nTF
    foo = abs(f - 1000*stimulusTFs(ff));
    fooMin = min(foo);
    fID = find(foo == fooMin);
    tfPhase(cc,ff) = y1Phase(fID,cc,ff);
  end
end
tfRelativePhase = zeros(nC, nTF);
for ff = 1:nTF
  tfRelativePhase(:,ff) = tfPhase(:,ff) - tfPhase(1,ff);
end

%%
%%%%%%%%%%%
% Plot it %
%%%%%%%%%%%

figure(1); clf;
panel = 1;
for cc = 1:nC
  for ff = 1:nTF
    subplot(nC,nTF,panel)
    plot(t,yAll(:,cc,ff));
    xlim([0 targetDuration]);
    set(gca,'xtick',[0:cropDuration:targetDuration]);
    title(['tf=',num2str(stimulusTFs(ff)),'; c=',num2str(contrasts(cc))]);
    drawPublishAxis
    panel = panel + 1;
  end
end

figure(2); clf;

% Change color map to gray scale
cmapVals = [nC-1:-1:0]' / nC;
cmap = repmat(cmapVals,1,3);
set(groot,'defaultAxesColorOrder',cmap);

subplot(2,1,1);
loglog(1000*stimulusTFs', tfTuning' ,'-o')
set(gca,'xtick',1000*stimulusTFs);
ylim([0.01 1]);
set(gca,'ytick',[0.01 0.02 0.05 0.1 0.2 0.5 1]);
drawPublishAxis

subplot(2,1,2);
loglog(1000*stimulusTFs', tfTuningSc' ,'-o')
set(gca,'xtick',1000*stimulusTFs);
ylim([0.01 1]);
set(gca,'ytick',[0.01 0.02 0.05 0.1 0.2 0.5 1]);
drawPublishAxis

print([figurePath,'tfTuning omega=',num2str(floor(1000*omega)),'.eps'],'-depsc','-painters');

% Restore color map
set(groot,'defaultAxesColorOrder',defaultColors);

figure(3); clf;

% Change color map to blue scale
baseColor = [0, 0.5, 1];
cmap = ([1:nTF]' / nTF) * baseColor;
set(groot,'defaultAxesColorOrder',cmap);

subplot(2,1,1);
semilogx(contrasts', (180/pi)*tfPhase ,'-o')
xlim([min(contrasts) max(contrasts)]);
set(gca,'xtick',contrasts);
ylim([-180 180]);
set(gca,'ytick',[-180:90:180]);
drawPublishAxis

subplot(2,1,2);
semilogx(contrasts', (180/pi)*tfRelativePhase ,'-o')
xlim([min(contrasts) max(contrasts)]);
set(gca,'xtick',contrasts);
ylim([-45 60]);
set(gca,'ytick',[-45:15:60]);
drawPublishAxis

print([figurePath,'tfPhase omega=',num2str(floor(1000*omega)),'.eps'],'-depsc','-painters');

% Restore color map
set(groot,'defaultAxesColorOrder',defaultColors);