
%% Parameters

parameters;

% Contrasts
cStep = 0.025;
c = 10.^[-2:cStep:0];
nC = length(c);

%% Responses 

% Tuning curves are raised cosines
[theta, deltaTheta, thetaPreferred, thetaRFs] = makeRFs(Ntheta, overlapTheta, 1, [-1 1]);
% Number of stimulus samples
Mtheta = length(theta);

preferredOrientation = 0;
nonpreferredOrientation = pi/12;
maskOrientation = pi/2;

%%%%%%%%%%%%%%%%%%%%%%%%%
% Preferred orientation %
%%%%%%%%%%%%%%%%%%%%%%%%%

s = zeros(Mtheta,1);
mm = floor(preferredOrientation / deltaTheta) + 1;
s(mm) = 1;

% Input drive 
z = (thetaRFs * s) * c;
zSqr = z.^2;

% Feedforward responses
sumZsqr = sum(zSqr);
y1 = zSqr ./ (repmat(sumZsqr,[Ntheta,1]) + sigma^2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Non-preferred orientation %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

s = zeros(Mtheta,1);
mm = floor(nonpreferredOrientation / deltaTheta) + 1;
s(mm) = 1;

% Input drive 
z = (thetaRFs * s) * c;
zSqr = z.^2;

% Feedforward responses
sumZsqr = sum(zSqr);
y2 = zSqr ./ (repmat(sumZsqr,[Ntheta,1]) + sigma^2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Preferred orientation + orthogonal mask %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

s1 = zeros(Mtheta,1);
mm = floor(preferredOrientation / deltaTheta) + 1;
s1(mm) = 1;
s2 = zeros(Mtheta,1);
mm = floor(maskOrientation / deltaTheta) + 1;
s2(mm) = 0.25;

% Input drive 
z = (thetaRFs * s1) * c + (thetaRFs * s2) * ones(size(c));
zSqr = z.^2;

% Feedforward responses
sumZsqr = sum(zSqr);
y3 = zSqr ./ (repmat(sumZsqr,[Ntheta,1]) + sigma^2);

%% Plot it

figure(1); clf;

responses = [y1(1,:)' y2(1,:)'];
responses = responses / (max(responses(:)));

semilogx(c,responses);
ylim([0 1]);
set(gca,'ytick',[0:0.5:1]);
xlabel('Contrast');
title('Preferred orientation and Non-preferred orientation');
drawPublishAxis

figure(2); clf;

responses = [y1(1,:)' y3(1,:)'];
responses = responses / (max(responses(:)));

semilogx(c,responses);
ylim([0 1]);
set(gca,'ytick',[0:0.5:1]);
xlabel('Contrast');
title('Preferred orientation with and without orthogonal mask');
drawPublishAxis
